==> mall-center-api-0.1.11-20211122.022520-16-sources.jar: cn/com/duiba/mall/center/api/domain/paramquary/groupbuy/GroupBuyActConfParam.java <==
package cn.com.duiba.mall.center.api.domain.paramquary.groupbuy;

import cn.com.duiba.mall.center.api.domain.paramquary.PageQueryParam;

import java.io.Serializable;
import java.util.Date;

/**
 * @author czw
 */
public class GroupBuyActConfParam extends PageQueryParam implements Serializable {
    private static final long serialVersionUID = -7086998134961128320L;

    /**
     * 主键
     */
    private Long id;

    /**
     * appid
     */
    private Long appId;

    /**
     * 活动名称
     */
    private String actTitle;

    /**
     * 商品id
     */
    private Long appItemId;

    /**
     * sku的信息目前就拼团价和skuId{"groupBuyPrice":"","skuId":""}
     */
    private String skuInfoJson;

    /**
     * 活动开始时间
     */
    private Date actStartTime;

    /**
     * 活动结束时间
     */
    private Date actEndTime;

    /**
     * 参团人数
     */
    private Integer groupPeopleNum;

    /**
     * 参团有效期  单位分
     */
    private Integer groupDuration;

    /**
     * 预告时长 单位分
     */
    private Integer foreshowDurtion;

    /**
     * 限购次数
     */
    private Integer limitNum;

    /**
     * 是否展现已拼数量 0否1是
     */
    private Integer showSaleNum;

    /**
     * 基数 0正常显示 大于0代表增加基数显示，小于0代表达到该数量显示
     */
    private Integer baseNum;

    /**
     * 是否可用 0失效 1可用
     */
    private Integer enable;

    /**
     * 失效时间
     */
    private Date failureTime;

    /**
     * 是否删除 0否1是
     */
    private Integer deleted;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getActTitle() {
        return actTitle;
    }

    public void setActTitle(String actTitle) {
        this.actTitle = actTitle;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getSkuInfoJson() {
        return skuInfoJson;
    }

    public void setSkuInfoJson(String skuInfoJson) {
        this.skuInfoJson = skuInfoJson;
    }

    public Date getActStartTime() {
        return actStartTime;
    }

    public void setActStartTime(Date actStartTime) {
        this.actStartTime = actStartTime;
    }

    public Date getActEndTime() {
        return actEndTime;
    }

    public void setActEndTime(Date actEndTime) {
        this.actEndTime = actEndTime;
    }

    public Integer getGroupPeopleNum() {
        return groupPeopleNum;
    }

    public void setGroupPeopleNum(Integer groupPeopleNum) {
        this.groupPeopleNum = groupPeopleNum;
    }

    public Integer getGroupDuration() {
        return groupDuration;
    }

    public void setGroupDuration(Integer groupDuration) {
        this.groupDuration = groupDuration;
    }

    public Integer getForeshowDurtion() {
        return foreshowDurtion;
    }

    public void setForeshowDurtion(Integer foreshowDurtion) {
        this.foreshowDurtion = foreshowDurtion;
    }

    public Integer getLimitNum() {
        return limitNum;
    }

    public void setLimitNum(Integer limitNum) {
        this.limitNum = limitNum;
    }

    public Integer getShowSaleNum() {
        return showSaleNum;
    }

    public void setShowSaleNum(Integer showSaleNum) {
        this.showSaleNum = showSaleNum;
    }

    public Integer getBaseNum() {
        return baseNum;
    }

    public void setBaseNum(Integer baseNum) {
        this.baseNum = baseNum;
    }

    public Integer getEnable() {
        return enable;
    }

    public void setEnable(Integer enable) {
        this.enable = enable;
    }

    public Date getFailureTime() {
        return failureTime;
    }

    public void setFailureTime(Date failureTime) {
        this.failureTime = failureTime;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}

==> mall-center-api-0.1.31.1-20230619.022756-1-sources.jar: cn/com/duiba/mall/center/api/domain/paramquary/groupbuy/GroupBuyActConfParam.java <==
package cn.com.duiba.mall.center.api.domain.paramquary.groupbuy;

import cn.com.duiba.mall.center.api.domain.paramquary.PageQueryParam;

import java.io.Serializable;
import java.util.Date;

/**
 * @author czw
 */
public class GroupBuyActConfParam extends PageQueryParam implements Serializable {
    private static final long serialVersionUID = -7086998134961128320L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 活动渠道
     */
    private Integer channelType;

    /**
     * appid
     */
    private Long appId;

    /**
     * 活动名称
     */
    private String actTitle;

    /**
     * 商品id
     */
    private Long appItemId;

    /**
     * sku的信息目前就拼团价和skuId{"groupBuyPrice":"","skuId":""}
     */
    private String skuInfoJson;

    /**
     * 活动开始时间
     */
    private Date actStartTime;

    /**
     * 活动结束时间
     */
    private Date actEndTime;

    /**
     * 参团人数
     */
    private Integer groupPeopleNum;

    /**
     * 参团有效期  单位分
     */
    private Integer groupDuration;

    /**
     * 预告时长 单位分
     */
    private Integer foreShowDuration;

    /**
     * 限购次数
     */
    private Integer limitNum;

    /**
     * 是否展现已拼数量 0否1是
     */
    private Integer showSaleNum;

    /**
     * 基数 0正常显示 大于0代表增加基数显示，小于0代表达到该数量显示
     */
    private Integer baseNum;

    /**
     * 是否可用 0失效 1可用
     */
    private Integer enable;

    /**
     * 失效时间
     */
    private Date failureTime;

    /**
     * 是否删除 0否1是
     */
    private Integer deleted;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getActTitle() {
        return actTitle;
    }

    public void setActTitle(String actTitle) {
        this.actTitle = actTitle;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public String getSkuInfoJson() {
        return skuInfoJson;
    }

    public void setSkuInfoJson(String skuInfoJson) {
        this.skuInfoJson = skuInfoJson;
    }

    public Date getActStartTime() {
        return actStartTime;
    }

    public void setActStartTime(Date actStartTime) {
        this.actStartTime = actStartTime;
    }

    public Date getActEndTime() {
        return actEndTime;
    }

    public void setActEndTime(Date actEndTime) {
        this.actEndTime = actEndTime;
    }

    public Integer getGroupPeopleNum() {
        return groupPeopleNum;
    }

    public void setGroupPeopleNum(Integer groupPeopleNum) {
        this.groupPeopleNum = groupPeopleNum;
    }

    public Integer getGroupDuration() {
        return groupDuration;
    }

    public void setGroupDuration(Integer groupDuration) {
        this.groupDuration = groupDuration;
    }

    public Integer getForeShowDuration() {
        return foreShowDuration;
    }

    public void setForeShowDuration(Integer foreShowDuration) {
        this.foreShowDuration = foreShowDuration;
    }

    public Integer getLimitNum() {
        return limitNum;
    }

    public void setLimitNum(Integer limitNum) {
        this.limitNum = limitNum;
    }

    public Integer getShowSaleNum() {
        return showSaleNum;
    }

    public void setShowSaleNum(Integer showSaleNum) {
        this.showSaleNum = showSaleNum;
    }

    public Integer getBaseNum() {
        return baseNum;
    }

    public void setBaseNum(Integer baseNum) {
        this.baseNum = baseNum;
    }

    public Integer getEnable() {
        return enable;
    }

    public void setEnable(Integer enable) {
        this.enable = enable;
    }

    public Date getFailureTime() {
        return failureTime;
    }

    public void setFailureTime(Date failureTime) {
        this.failureTime = failureTime;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

}
